@@ -11,12 +11,11 @@ from urllib.request import urlopen
 from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
 from email.mime.multipart import MIMEMultipart
-
-from croniter import croniter
 from flask.wrappers import Response
 
 import jwt
 import boto3
+import botocore
 from botocore.exceptions import NoCredentialsError
 import flask
 import requests
@@ -46,7 +45,7 @@ if storage_name == 's3':
 elif storage_name == 'ceph':
     ACCESS_KEY_ID = os.getenv('ACCESS_KEY_ID')
     SECRET_ACCESS_KEY = os.getenv('SECRET_ACCESS_KEY')
-    BUCKET_NAME = os.getenv('BUCKET_NAME')
+    BUCKET_NAME = os.getenv('BUCKET_NAME', 'analytics-apps')
     ENDPOINT_URL = os.getenv('ENDPOINT_URL')
 else:
     logger.info("No storages are found")
@@ -177,8 +176,9 @@ def get_epoc_from_datetime_string(str_datetime):
 
 def get_result_by_run(run_id, field=None, default_value=None):
     try:
-        run_id= f'{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
+        # run_id= f'{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
         if storage_name == 's3':
+            run_id= f'{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
             s3 = get_s3_client()
             res_object = s3.get_object(Bucket=BUCKET_NAME,Key=run_id)
             serializedObject = res_object['Body'].read()
@@ -187,6 +187,7 @@ def get_result_by_run(run_id, field=None, default_value=None):
                 result = result.get(field, default_value)
             return result
         elif storage_name == 'ceph':
+            run_id= f'{APP_ID.lower()}/{run_id}/json/{run_id}'
             s3 = get_ceph_resource()
             data = BytesIO()
             res_object = s3.Bucket(BUCKET_NAME).download_fileobj(Fileobj=data,Key=run_id)   
@@ -292,13 +293,20 @@ def upload_to_storage(content, location):
             bucket_check = s3.Bucket(BUCKET_NAME) in s3.buckets.all()
             
             if bucket_check:
-                logging.info(f'{BUCKET_NAME} Bucket already exists!')
+                logger.info(f'{BUCKET_NAME} Bucket already exists!')
             else:
-                logging.info(f'{BUCKET_NAME} Bucket does not exist!')
-                bucket = s3.Bucket(BUCKET_NAME)
-                bucket.create()
-                logger.info(f'{BUCKET_NAME} bucket created...')
-
+                logger.info(f'{BUCKET_NAME} Bucket does not exist!')
+                try:
+                    bucket = s3.Bucket(BUCKET_NAME)
+                    bucket.create()
+                except botocore.parsers.ResponseParserError as error:
+                #Bucket is created is successfully, but throwing an error. So that we are catching and passing that error(But not throwing that error)
+                    bucket_check = s3.Bucket(BUCKET_NAME) in s3.buckets.all()
+                    if bucket_check:
+                        logger.info(f'{BUCKET_NAME} bucket created...')
+                    else:
+                        logger.info(f'{BUCKET_NAME} bucket is not created...')
+                    pass
             
             s3.Bucket(BUCKET_NAME).put_object(Bucket=BUCKET_NAME,
                                             Key=location,
@@ -381,33 +389,20 @@ def update_results_url(gen_start_time, analysisRunId, tenantId, json_result_url=
 
     url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
     
-    if pdf_result_url == None:
-        data={
-                "status" : status,
-                "resultUrl" : json_result_url,
-                "xlsxFilePath" : excel_result_url,
-                "repGenStartTime" : gen_start_time,
-                "repGenEndTime" : gen_completed_time,
-                "failureReason" : failure_reason
-        }
-    elif excel_result_url == None:
-        data={
-                "status" : status,
-                "resultUrl" : json_result_url,
-                "pdfFilePath" : pdf_result_url,
-                "repGenStartTime" : gen_start_time,
-                "repGenEndTime" : gen_completed_time,
-                "failureReason" : failure_reason
-        }
-    else:
-        data={
-                "status" : status,
-                "resultUrl" : json_result_url,
-                "pdfFilePath" : pdf_result_url,
-                "xlsxFilePath" : excel_result_url,
-                "repGenStartTime" : gen_start_time,
-                "repGenEndTime" : gen_completed_time,
-                "failureReason" : failure_reason
+    if storage_name == 'ceph':
+        if excel_result_url is not None:
+            excel_result_url = f'{BUCKET_NAME}/{excel_result_url}'
+        if pdf_result_url is not None:
+            pdf_result_url = f'{BUCKET_NAME}/{pdf_result_url}'
+            
+    data={
+            "status" : status,
+            "resultUrl" : json_result_url,
+            "pdfFilePath" : pdf_result_url,
+            "xlsxFilePath" : excel_result_url,
+            "repGenStartTime" : gen_start_time,
+            "repGenEndTime" : gen_completed_time,
+            "failureReason" : failure_reason
         }
 
     api_proce_before_time = time.time()
@@ -506,3 +501,69 @@ def upload_excel(analysis_run, excel_file):
     s3_path = f'{analysis_run.analysis.app.slug}/excel/{timestamp}.xlsx'
 
     return upload_to_storage(excel_file, s3_path)
+
+
+"""
+Method to read summary response and get the required values to showcase in the summary / overview pages of the result files
+Inpute values:
+    param1: run_id - actual run id of the generated run
+    param2: summary_key - this is the key which is stored with summary response of a run in the metafile(json) stored in the cloud
+    param3: value_by - defines the which type information is requested by end user.
+        values:
+            client_logo
+            partner_logo
+            client_name
+            partner_name
+            description
+            last_run
+"""
+def get_summary_details(run_id, summary_key, value_by):
+    value = ''
+    if value_by is None or summary_key is None:
+        return value
+    if (len(value_by) == 0 or len(summary_key) == 0):
+        return value
+    summary_response = get_result_by_run(run_id, summary_key, {})
+    if len(summary_response) <= 0:
+        return value
+
+    if value_by == 'client_logo':
+        return get_tenant_logo(summary_response, 'client')
+    elif value_by == 'partner_logo':
+        return get_tenant_logo(summary_response, 'partner')
+    elif value_by == 'last_run':
+        return get_last_run(summary_response)
+    elif value_by == 'description':
+        return get_app_description(summary_response)
+    elif value_by == 'partner_name':
+        return get_tenant_name(summary_response, 'partner')
+    elif value_by == 'client_name':
+        return get_tenant_name(summary_response, 'client')
+    else:
+        return value
+
+
+def get_tenant_logo(summary_res, context):
+    logo = ''
+    if context == 'partner':
+        logo = summary_res['partner_logo_path']
+    else:
+        logo = summary_res['client_logo_path']
+    return logo
+
+
+def get_tenant_name(summary_res, context):
+    name = ''
+    if context == 'client':
+        name = summary_res['client_name']
+    else:
+        name = summary_res['partner_name']
+    return name
+
+
+def get_last_run(summary_res):
+    return summary_res['create_date']
+
+
+def get_app_description(summary_res):
+    return summary_res['app_description']
